@@ -1,3 +1,5 @@
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+
 /* Metacity interface for talking to GTK+ UI module */
 
 /* 
@@ -28,11 +30,10 @@
 #include "menu.h"
 #include "core.h"
 #include "theme.h"
+#include "iconcache.h"
 
 #include "inlinepixbufs.h"
 
-#include <pango/pangox.h>
-
 #include <string.h>
 #include <stdlib.h>
 
@@ -434,16 +435,16 @@ meta_image_window_set (MetaImageWindow *iw,
    * and this way flicker is genuinely zero.
    */
 
-  gdk_pixbuf_render_to_drawable (pixbuf,
-                                 iw->pixmap,
-                                 iw->window->style->black_gc,
-                                 0, 0,
-                                 0, 0,
-                                 gdk_pixbuf_get_width (pixbuf),
-                                 gdk_pixbuf_get_height (pixbuf),
-                                 GDK_RGB_DITHER_NORMAL,
-                                 0, 0);
-  
+  gdk_draw_pixbuf (iw->pixmap,
+                   iw->window->style->black_gc,
+		   pixbuf,
+                   0, 0,
+                   0, 0,
+                   gdk_pixbuf_get_width (pixbuf),
+                   gdk_pixbuf_get_height (pixbuf),
+                   GDK_RGB_DITHER_NORMAL,
+                   0, 0);
+
   gdk_window_set_back_pixmap (iw->window->window,
                               iw->pixmap,
                               FALSE);
@@ -734,6 +735,7 @@ meta_ui_set_current_theme (const char *name,
                            gboolean    force_reload)
 {
   meta_theme_set_current (name, force_reload);
+  meta_invalidate_default_icons ();
 }
 
 gboolean
@@ -821,7 +823,7 @@ meta_ui_accelerator_name  (unsigned int        keysym,
         
   if (keysym == 0 && mask == 0)
     {
-      return strdup ("disabled");
+      return g_strdup ("disabled");
     }
 
   if (mask & META_VIRTUAL_SHIFT_MASK)
